@@ -7,7 +7,7 @@
 #include <libgnomevfs/gnome-vfs-resolve.h>
 #include <libgnomevfs/gnome-vfs-dns-sd.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
-#include <pyorbit.h>
+#include "pygnomevfsbonobo.h"
 
 static GHashTable *monitor_hash;
 static gint monitor_id_counter = 0;
@@ -67,6 +67,14 @@ static PyTypeObject *_PyGObject_Type;
 
 extern void pygvvolume_add_constants(PyObject *m);
 
+static void
+pygvfs_lazy_load_pygnomevfsbonobo(void)
+{
+    static PyObject *pygnomevfs_module = NULL;
+    if (!pygnomevfs_module)
+        pygnomevfs_module = pygnome_vfs_bonobo_init();
+}
+
 
 gboolean
 pygnome_vfs_result_check(GnomeVFSResult result)
@@ -1173,16 +1181,8 @@ pygvfs_mime_action_new(GnomeVFSMimeAction *action)
 			     pygvfs_mime_application_new(action->action.application));
 
     case GNOME_VFS_MIME_ACTION_TYPE_COMPONENT: {
-	CORBA_any any;
-	PyObject *component;
-	any._type = TC_Bonobo_ServerInfo;
-	any._value = action->action.application;
-	component = pyorbit_demarshal_any(&any);
-	if (!component) {
-	    PyErr_SetString(PyExc_TypeError, "unable to convert Bonobo_ServerInfo of component");
-	    return NULL;
-	}
-	return Py_BuildValue("(iN)", action->action_type, component);
+        pygvfs_lazy_load_pygnomevfsbonobo();
+        return pygnomevfs_bonobo_mime_component_action_new(action);
     }
     default:
 	PyErr_SetString(PyExc_ValueError, "unknown action type returned");
@@ -1210,91 +1210,6 @@ pygvfs_mime_get_default_action(PyObject *self, PyObject *args, PyObject *kwargs)
     return retval;
 }
 
-static PyObject *
-pygvfs_mime_get_default_component(PyObject *self, PyObject *args, PyObject *kwargs)
-{
-    static char *kwlist[] = { "mime_type", NULL };
-    char *mime_type;
-    Bonobo_ServerInfo *component;
-    PyObject *py_component;
-    CORBA_any any;
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s:gnomevfs.mime_get_default_component",
-				     kwlist, &mime_type))
-	return NULL;
-    if (!(component = gnome_vfs_mime_get_default_component(mime_type))) {
-        Py_INCREF(Py_None);
-        return Py_None;
-    }
-    any._type = TC_Bonobo_ServerInfo;
-    any._value = component;
-    py_component = pyorbit_demarshal_any(&any);
-    if (!component) {
-	PyErr_SetString(PyExc_TypeError, "unable to convert Bonobo_ServerInfo of component");
-	return NULL;
-    }
-    CORBA_free(component);
-    return py_component;
-}
-
-static PyObject *
-pygvfs_mime_components_list_new(GList *list)
-{
-    PyObject *retval;
-    Bonobo_ServerInfo *component;
-    PyObject *py_component;
-    CORBA_any any;
-    guint i, len = g_list_length(list);
-    
-    retval = PyList_New(len);
-    for (i = 0; list; ++i, list = list->next) {
-	g_assert(i < len);
-	component = (Bonobo_ServerInfo *) list->data;
-	any._value = component;
-	py_component = pyorbit_demarshal_any(&any);
-	if (!component) {
-	    PyErr_SetString(PyExc_TypeError, "unable to convert Bonobo_ServerInfo of component");
-	    Py_DECREF(retval);
-	    return NULL;
-	}
-	PyList_SET_ITEM(retval, i, py_component);
-    }
-    return retval;
-}
-
-static PyObject *
-pygvfs_mime_get_short_list_components(PyObject *self, PyObject *args, PyObject *kwargs)
-{
-    static char *kwlist[] = { "mime_type", NULL };
-    char *mime_type;
-    GList *list;
-    PyObject *py_list;
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s:gnomevfs.mime_get_short_list_components",
-				     kwlist, &mime_type))
-	return NULL;
-    list = gnome_vfs_mime_get_short_list_components(mime_type);
-    py_list = pygvfs_mime_components_list_new(list);
-    gnome_vfs_mime_component_list_free(list);
-    return py_list;
-}
-
-static PyObject *
-pygvfs_mime_get_all_components(PyObject *self, PyObject *args, PyObject *kwargs)
-{
-    static char *kwlist[] = { "mime_type", NULL };
-    char *mime_type;
-    GList *list;
-    PyObject *py_list;
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s:gnomevfs.mime_get_all_components",
-				     kwlist, &mime_type))
-	return NULL;
-    list = gnome_vfs_mime_get_all_components(mime_type);
-    py_list = pygvfs_mime_components_list_new(list);
-    gnome_vfs_mime_component_list_free(list);
-    return py_list;
-}
 
 static PyObject *
 pygvfs_mime_applications_list_new(GList *list)
@@ -2137,16 +2052,10 @@ static PyMethodDef pygnomevfs_functions[] = {
       METH_VARARGS|METH_KEYWORDS },
     { "mime_get_default_action", (PyCFunction)pygvfs_mime_get_default_action,
       METH_VARARGS|METH_KEYWORDS },
-    { "mime_get_default_component", (PyCFunction)pygvfs_mime_get_default_component,
-      METH_VARARGS|METH_KEYWORDS },
-    { "mime_get_short_list_components", (PyCFunction)pygvfs_mime_get_short_list_components,
-      METH_VARARGS|METH_KEYWORDS },
     { "mime_get_short_list_applications", (PyCFunction)pygvfs_mime_get_short_list_applications,
       METH_VARARGS|METH_KEYWORDS },
     { "mime_get_all_applications", (PyCFunction)pygvfs_mime_get_all_applications,
       METH_VARARGS|METH_KEYWORDS },
-    { "mime_get_all_components", (PyCFunction)pygvfs_mime_get_all_components,
-      METH_VARARGS|METH_KEYWORDS },
     { "mime_set_default_action_type", (PyCFunction)pygvfs_mime_set_default_action_type,
       METH_VARARGS|METH_KEYWORDS },
     { "mime_set_default_application", (PyCFunction)pygvfs_mime_set_default_application,
@@ -2483,7 +2392,7 @@ pygnomefs_register_gobject_based_classes(PyObject *d)
 }
 
 DL_EXPORT(void)
-initgnomevfs(void)
+init_gnomevfs(void)
 {
     PyObject *m, *d, *o;
 
@@ -2494,7 +2403,6 @@ initgnomevfs(void)
     PyGnomeVFSHandle_Type.ob_type = &PyType_Type;
 
     init_pygobject();
-    init_pyorbit();
     if (!gnome_vfs_init()) {
 	PyErr_SetString(PyExc_RuntimeError, "could not initialise gnomevfs");
 	return;
@@ -2513,7 +2421,7 @@ initgnomevfs(void)
     if (PyType_Ready(&PyGnomeVFSXferProgressInfo_Type) < 0)
 	return;
 
-    m = Py_InitModule("gnomevfs", pygnomevfs_functions);
+    m = Py_InitModule("gnomevfs._gnomevfs", pygnomevfs_functions);
     d = PyModule_GetDict(m);
 
     register_constants(m);
